local L_MESSAGE = "%s died with icon {rt%d} (%s)."

local frame = CreateFrame("Frame", nil, InterfaceOptionsFramePanelContainer)
frame.name = "IconLover"
frame:Hide()

local icons = {RAID_TARGET_1, RAID_TARGET_2, RAID_TARGET_3, RAID_TARGET_4, RAID_TARGET_5, RAID_TARGET_6, RAID_TARGET_7, RAID_TARGET_8}
local editboxes = {}

local function save(editbox)
	local healer = editbox:GetText()
	IconLoverDB[editbox.iconIndex] = healer
	editbox:SetTextColor(1, 1, 1, 1)
	EditBox_HandleTabbing(editbox, editboxes)
end

local function tab(self)
	if not AutoCompleteEditBox_OnTabPressed(self) then
		save(self)
	end
end
local function focusLost(self)
	AutoCompleteEditBox_OnEditFocusLost(self)
	EditBox_ClearHighlight(self)
end
local function enter(self)
	if not AutoCompleteEditBox_OnEnterPressed(self) then
		save(self)
	end
end
local function escape(self)
	if not AutoCompleteEditBox_OnEscapePressed(self) then
		EditBox_ClearFocus(self)
	end
end
local function textChanged(self)
	AutoCompleteEditBox_OnTextChanged(self, userInput)
	self:SetTextColor(1, 0, 0, 1)
end

frame:SetScript("OnShow", function(self)
	local title = self:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	title:SetPoint("TOPLEFT", 16, -16)
	title:SetText("IconLover")

	local subtitle = self:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	subtitle:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -8)
	subtitle:SetWidth(frame:GetWidth() - 24)
	subtitle:SetJustifyH("LEFT")
	subtitle:SetJustifyV("TOP")
	subtitle:SetText("Assign icons to healers. If anyone in your group is killed with a raid icon assigned to them, the person listed here next to the icon will be announced in raid chat. Play the blame game!")

	for i = 1, #icons do
		local edit = CreateFrame("EditBox", "IconLoverEditBox"..i, self, "AutoCompleteEditBoxTemplate")
		edit.autoCompleteParams = AUTOCOMPLETE_LIST.IN_GROUP
		edit.addHighlightedText = true
		edit:SetScript("OnTabPressed", tab)
		edit:SetScript("OnEditFocusLost", focusLost)
		edit:SetScript("OnEnterPressed", enter)
		edit:SetScript("OnEscapePressed", escape)
		edit:SetScript("OnTextChanged", textChanged)
		edit:SetWidth(100)
		edit:SetHeight(20)
		edit:SetFontObject(ChatFontNormal)
		edit:SetAutoFocus(false)
		edit:ClearFocus()
		edit:SetTextInsets(0, 0, 3, 3)
		edit.iconIndex = i

		local left = edit:CreateTexture(nil, "BACKGROUND")
		left:SetTexture([[Interface\Common\Common-Input-Border]])
		left:SetWidth(8)
		left:SetHeight(20)
		left:SetPoint("TOPLEFT", -8, 0)
		left:SetTexCoord(0, 0.0625, 0, 0.625)

		local middle = edit:CreateTexture(nil, "BACKGROUND")
		middle:SetTexture([[Interface\Common\Common-Input-Border]])
		middle:SetWidth(100)
		middle:SetHeight(20)
		middle:SetPoint("LEFT", left, "RIGHT")
		middle:SetTexCoord(0.0625, 0.9375, 0, 0.625)

		local right = edit:CreateTexture(nil, "BACKGROUND")
		right:SetTexture([[Interface\Common\Common-Input-Border]])
		right:SetWidth(8)
		right:SetHeight(20)
		right:SetPoint("LEFT", middle, "RIGHT")
		right:SetTexCoord(0.9375, 1, 0, 0.625)

		local text = edit:CreateFontString()
		text:SetWidth(60)
		text:SetJustifyH("RIGHT")
		text:SetFontObject(GameFontHighlight)
		text:SetText(icons[i])

		table.insert(editboxes, edit:GetName())

		if i == 1 then
			text:SetPoint("TOPLEFT", subtitle, "BOTTOMLEFT", 0, -50)
		else
			text:SetPoint("TOPLEFT", _G[editboxes[i - 1]].text, "BOTTOMLEFT", 0, -8)
		end
		edit:SetPoint("LEFT", text, "RIGHT", 12, 0)
		edit.text = text
		edit:SetText(IconLoverDB[i] or "")
	end

	frame:SetScript("OnShow", nil)
end)
InterfaceOptions_AddCategory(frame)

local f = CreateFrame("Frame")
local inRaid = nil
f:SetScript("OnEvent", function(self, event, _, clEvent, _, _, _, _, player)
	if event == "RAID_ROSTER_UPDATE" then
		if UnitInRaid("player") and not inRaid then
			inRaid = true
			self:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
		elseif not UnitInRaid("player") and inRaid then
			inRaid = nil
			self:UnregisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
		end
	elseif event == "VARIABLES_LOADED" then
		IconLoverDB = IconLoverDB or {}
	else
		if clEvent == "UNIT_DIED" and UnitInRaid(player) then
			local icon = GetRaidTargetIndex(player)
			if not icon or not IconLoverDB[icon] then return end
			if not UnitInRaid(IconLoverDB[icon]) then return end
			SendChatMessage(L_MESSAGE:format(player, icon, IconLoverDB[icon]), "RAID")
		end
	end
end)
f:RegisterEvent("RAID_ROSTER_UPDATE")
f:RegisterEvent("VARIABLES_LOADED")

